@@ -22,9 +22,6 @@ import sys
 
 from astkit import ast
 
-from instrumental.constructs import BooleanDecision
-from instrumental.constructs import LogicalAnd
-from instrumental.constructs import LogicalOr
 from instrumental.pragmas import PragmaFinder
 
 def __setup_recorder(): # pragma: no cover
@@ -41,6 +38,7 @@ def get_setup():
     return setup
 
 class ExecutionRecorder(object):
+    DEFAULT_TAG = 'X'
     
     @classmethod
     def reset(cls):
@@ -54,44 +52,19 @@ class ExecutionRecorder(object):
         return cls._instance
     
     def __init__(self):
-        self._next_label = 1
-        self._constructs = {}
-        self._sources = {}
-        self._statements = {}
-        self._branches = {}
-        self.pragmas = {}
+        self.metadata = {}
         self.recording = False
-        
+        self.tag = None
+        self._tagging = False
+    
     def start(self):
         self.recording = True
     
     def stop(self):
         self.recording = False
     
-    def add_source(self, modulename, source):
-        self._sources[modulename] = source
-        self.pragmas[modulename] = self._find_pragmas(source)
-    
-    def _find_pragmas(self, source):
-        finder = PragmaFinder()
-        return finder.find_pragmas(source)
-    
-    @property
-    def sources(self):
-        return self._sources
-    
-    @property
-    def constructs(self):
-        return self._constructs
-    
-    @property
-    def statements(self):
-        return self._statements
-    
-    def next_label(self):
-        label = self._next_label
-        self._next_label += 1
-        return label
+    def add_metadata(self, metadata):
+        self.metadata[metadata.modulename] = metadata
     
     @staticmethod
     def get_recorder_call():
@@ -103,37 +76,22 @@ class ExecutionRecorder(object):
         kall.keywords = []
         return kall
     
-    def record(self, arg, label, *args, **kwargs):
-        if self.recording:
-            self._constructs[label].record(arg, *args, **kwargs)
+    def record(self, arg, modulename, label, *args, **kwargs):
+        if self.recording and label in self.metadata[modulename].constructs:
+            kwargs['tag'] = (self.tag 
+                             if self.tag is not None 
+                             else self.DEFAULT_TAG)
+            self.metadata[modulename].constructs[label].record(arg, 
+                                                               *args, **kwargs)
         return arg
     
-    def add_BoolOp(self, modulename, node, pragmas, parent):
-        if isinstance(node.op, ast.And):
-            construct_klass = LogicalAnd
-        elif isinstance(node.op, ast.Or):
-            construct_klass = LogicalOr
-        else:
-            raise TypeError("Expected a BoolOp node with an op field of ast.And or ast.Or")
-        construct = construct_klass(modulename, node, parent)
-        for pragma in pragmas:
-            construct = pragma(construct)
-        
-        label = self.next_label()
-        self._constructs[label] = construct
-        
+    def add_BoolOp(self, modulename, label, node, pragmas, parent):
         # Now wrap the individual values in recorder calls
         base_call = self.get_recorder_call()
         base_call.args = \
-            [ast.Num(n=label, lineno=node.lineno, col_offset=node.col_offset)]
+            [ast.Str(s=modulename, lineno=node.lineno, col_offset=node.col_offset),
+             ast.Str(s=label, lineno=node.lineno, col_offset=node.col_offset)]
         for i, value in enumerate(node.values):
-            # Try to determine if the condition is a literal
-            # Maybe we can do something with this information?
-            try:
-                literal = ast.literal_eval(value)
-                construct.literals[i] = literal
-            except ValueError:
-                pass
             recorder_call = deepcopy(base_call)
             recorder_call.args.insert(0, node.values[i])
             recorder_call.args.append(ast.copy_location(ast.Num(n=i), node.values[i]))
@@ -141,16 +99,23 @@ class ExecutionRecorder(object):
         ast.fix_missing_locations(node)
         return node
     
-    def add_test(self, modulename, node):
-        label = self.next_label()
-        construct = BooleanDecision(modulename, node)
-        self._constructs[label] = construct
-        
+    def add_test(self, modulename, label, node):
         base_call = ast.copy_location(self.get_recorder_call(),
                                       node)
         base_call.args = \
             [node,
-             ast.Num(n=label, lineno=node.lineno, col_offset=node.col_offset)]
+             ast.Str(s=modulename, lineno=node.lineno, col_offset=node.col_offset),
+             ast.Str(s=label, lineno=node.lineno, col_offset=node.col_offset)]
+        ast.fix_missing_locations(base_call)
+        return base_call
+    
+    def add_comparison(self, modulename, label, node):
+        base_call = ast.copy_location(self.get_recorder_call(),
+                                      node)
+        base_call.args = \
+            [node,
+             ast.Str(s=modulename, lineno=node.lineno, col_offset=node.col_offset),
+             ast.Str(s=label, lineno=node.lineno, col_offset=node.col_offset)]
         ast.fix_missing_locations(base_call)
         return base_call
     
@@ -169,13 +134,18 @@ class ExecutionRecorder(object):
         return kall_stmt
     
     def record_statement(self, modulename, lineno):
-        if self.recording:
-            self._statements[modulename][lineno] = True
+        if self.recording and lineno in self.metadata[modulename].lines:
+            self.metadata[modulename].lines[lineno] = True
     
     def add_statement(self, modulename, node):
-        lines = self._statements.setdefault(modulename, {})
-        lines[node.lineno] = False
         marker = self.get_statement_recorder_call(modulename, node.lineno)
         marker = ast.copy_location(marker, node)
         ast.fix_missing_locations(marker)
         return marker
+    
+    def merge(self, other):
+        for metadata in other.metadata.values():
+            if metadata.modulename not in self.metadata:
+                self.add_metadata(metadata)
+            else:
+                self.metadata[metadata.modulename].merge(metadata)
